==> unit-1.0.41-sources.jar: io/intino/goros/unit/box/ui/displays/items/TasksTableCountMessagesItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class TasksTableCountMessagesItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Task, UnitBox> {
	public _28_61_11449374513 _28_61_11449374513;
	public TasksTableCountMessagesItem._28_61_11449374513. CountMessages countMessages;

    public TasksTableCountMessagesItem(UnitBox box) {
        super(box);
        id("a_376711273");
    }

    @Override
	public void init() {
		super.init();
		if (_28_61_11449374513 == null) _28_61_11449374513 = register(new _28_61_11449374513(box()).<_28_61_11449374513>id("a_543211426").owner(TasksTableCountMessagesItem.this));
		if (_28_61_11449374513 != null) countMessages = _28_61_11449374513.countMessages;
	}

	public class _28_61_11449374513 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public TasksTableCountMessagesItem._28_61_11449374513. CountMessages countMessages;

		public _28_61_11449374513(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (countMessages == null) countMessages = register(new CountMessages(box()).<CountMessages>id("a1774596991").owner(TasksTableCountMessagesItem.this));
		}

		public class CountMessages extends io.intino.alexandria.ui.displays.components.Number<io.intino.alexandria.ui.displays.notifiers.NumberNotifier, UnitBox>  {

			public CountMessages(UnitBox box) {
				super(box);
				_value(0.0);
			}

			@Override
			public void init() {
				super.init();
			}
		}
	}
}

==> unit-1.1.1-sources.jar: io/intino/goros/unit/box/ui/displays/items/TasksTableCountMessagesItem.java <==
package io.intino.goros.unit.box.ui.displays.items;

import io.intino.alexandria.core.Box;
import io.intino.alexandria.exceptions.*;
import io.intino.alexandria.ui.displays.components.*;
import io.intino.goros.unit.box.ui.*;

import io.intino.goros.unit.box.UnitBox;

import io.intino.goros.unit.box.ui.displays.templates.*;






import io.intino.goros.unit.box.ui.displays.items.*;
import io.intino.goros.unit.box.ui.displays.rows.*;
import io.intino.alexandria.ui.displays.notifiers.ItemNotifier;

public class TasksTableCountMessagesItem extends io.intino.alexandria.ui.displays.components.Item<ItemNotifier, org.monet.space.kernel.model.Task, UnitBox> {
	public _28_61_11449374513 _28_61_11449374513;
	public TasksTableCountMessagesItem._28_61_11449374513. CountMessages countMessages;

    public TasksTableCountMessagesItem(UnitBox box) {
        super(box);
        id("a_376711273");
    }

    @Override
	public void init() {
		super.init();
		if (_28_61_11449374513 == null) _28_61_11449374513 = register(new _28_61_11449374513(box()).<_28_61_11449374513>id("a_543211426").owner(TasksTableCountMessagesItem.this));
		if (_28_61_11449374513 != null) countMessages = _28_61_11449374513.countMessages;
	}

    @Override
    public void remove() {
        super.remove();
	    if (_28_61_11449374513 != null) _28_61_11449374513.unregister();
	}

	public class _28_61_11449374513 extends io.intino.alexandria.ui.displays.components.Block<io.intino.alexandria.ui.displays.notifiers.BlockNotifier, UnitBox>  {
		public TasksTableCountMessagesItem._28_61_11449374513. CountMessages countMessages;

		public _28_61_11449374513(UnitBox box) {
			super(box);
		}

		@Override
		public void init() {
			super.init();
			if (countMessages == null) countMessages = register(new CountMessages(box()).<CountMessages>id("a1774596991").owner(TasksTableCountMessagesItem.this));
		}

		@Override
		public void unregister() {
		    super.unregister();
			if (countMessages != null) countMessages.unregister();
		}

		public class CountMessages extends io.intino.alexandria.ui.displays.components.Number<io.intino.alexandria.ui.displays.notifiers.NumberNotifier, UnitBox>  {

			public CountMessages(UnitBox box) {
				super(box);
				_value(0.0);
			}

			@Override
			public void init() {
				super.init();
			}

			@Override
			public void unregister() {
			    super.unregister();
			}
		}
	}
}
